@@ -10,6 +10,7 @@ with qw(Data::Stream::Bulk);
 has array => (
 	isa => "ArrayRef",
 	reader  => "_array",
+	writer  => "_set_array",
 	clearer => "_clear_array",
 	predicate => "_has_array",
 	required => 1,
@@ -31,6 +32,38 @@ sub next {
 	}
 }
 
+# squish several arrays into one
+sub list_cat {
+	my ( $self, @rest ) = @_;
+
+	return $self unless @rest;
+
+	my @arrays = ( $self );
+
+	# fetch all adjacent arrays
+	push @arrays, shift @rest while @rest and $rest[0]->isa(__PACKAGE__);
+
+	if ( @arrays > 1 ) {
+		my @cat;
+		push @cat, @$_ for map { $_->_array } @arrays;
+		return __PACKAGE__->new(
+			array => \@cat,
+		)->cat( @rest );
+	} else {
+		my $head = shift @rest;
+		return ( $self, $head->list_cat(@rest) );
+	}
+}
+
+sub filter {
+	my ( $self, $filter ) = @_;
+	local $_ = $self->next;
+	$self->_set_array( $filter->($_) );
+	return $self;
+}
+
+sub loaded { 1 }
+
 __PACKAGE__->meta->make_immutable;
 
 __PACKAGE__
@@ -79,6 +112,18 @@ Returns the array reference on the first invocation, and nothing thereafter.
 
 Returns true if C<next> has been called.
 
+=item list_cat
+
+Squishes adjacent arrays into a new array.
+
+=item filter $filter
+
+Immediately applies C<$filter> to the internal array and returns C<$self>.
+
+=item loaded
+
+Returns true
+
 =back
 
 =cut
