@@ -7,10 +7,25 @@ use namespace::clean -except => 'meta';
 
 with qw(Data::Stream::Bulk);
 
+sub items { return () }
+
+sub all { return () }
+
 sub next { undef }
 
 sub is_done { 1 }
 
+sub list_cat {
+	my ( $self, $head, @rest ) = @_;
+
+	return () unless $head;
+	return $head->list_cat(@rest);
+}
+
+sub filter { return $_[0] };
+
+sub loaded { 1 }
+
 __PACKAGE__->meta->make_immutable;
 
 __PACKAGE__
@@ -43,8 +58,25 @@ Always returns true.
 
 Always returns undef.
 
+=item items
+
+=item all
+
+Always returns the empty list.
+
+=item list_cat
+
+Skips $self
+
+=item filter
+
+Returns $self
+
+=item loaded
+
+Returns true.
+
 =back
 
 =cut
 
-
